==> client-sdk-react-1.8.1.tgz: package/src/components/Participants/ParticipantsSpeakerView/ParticipantsSpeakerView.tsx <==
import React, { useEffect, useState } from 'react'
import classNames from 'classnames'
import { Participant, ParticipantProps } from '../../Participant'
import { useZocksStore } from '../../../app'
import { ParticipantModel, selectLocalParticipant } from '../../../store'
import { usePagedParticipants, useSortRemoteParticipantsBySpeakers } from '../hooks'
import { MultipleParticipantViewProps } from '../model'
import './ParticipantsSpeakerView.scss'

export const ParticipantsSpeakerView: React.FC<MultipleParticipantViewProps> = ({
  pageSize = 4,
  participantElement,
}) => {
  const localParticipant = useZocksStore(selectLocalParticipant)

  const { remoteParticipantsSortedBySpeakers } = useSortRemoteParticipantsBySpeakers()
  const remoteParticipantsExist = !!remoteParticipantsSortedBySpeakers.length

  const mainParticipant = remoteParticipantsExist ? remoteParticipantsSortedBySpeakers[0] : localParticipant
  const allParticipants = [localParticipant, ...remoteParticipantsSortedBySpeakers]
  const { displayedParticipants, hasNextPage, hasPreviousPage, nextPage, previousPage } = usePagedParticipants(
    allParticipants,
    pageSize
  )

  const ParticipantElement = participantElement ?? Participant

  return (
    <div className='participants-speaker-view'>
      <div
        className={classNames('participants-speaker-view__main-speaker', {
          'participants-speaker-view__only-speaker': !remoteParticipantsExist,
        })}
      >
        {mainParticipant && (
          <MainParticipant mainParticipant={mainParticipant} participantElement={ParticipantElement} />
        )}
      </div>
      {remoteParticipantsExist && (
        <>
          {hasPreviousPage && <PreviousButton onClick={previousPage} />}
          <div className='participants-speaker-view__others-container'>
            <div className='participants-speaker-view__others'>
              {displayedParticipants.map((participant) => (
                <ParticipantElement key={participant.id} participant={participant} />
              ))}
            </div>
          </div>
          {hasNextPage && <NextButton onClick={nextPage} />}
        </>
      )}
    </div>
  )
}

const MainParticipant: React.FC<{
  mainParticipant: ParticipantModel
  participantElement: React.FC<ParticipantProps>
}> = ({ mainParticipant, participantElement }) => {
  const SPEAKER_CHANGE_DELAY = 1000

  const [participant1, setParticipant1] = useState<ParticipantModel>(mainParticipant)
  const [participant2, setParticipant2] = useState<ParticipantModel>(mainParticipant)
  const [showParticipant1, setShowParticipant1] = useState<boolean>(true)

  const displayedParticipantId = showParticipant1 ? participant1.id : participant2.id

  useEffect(() => {
    if (mainParticipant.id !== displayedParticipantId) {
      const timeout = setTimeout(() => setShowParticipant1((showP1) => !showP1), SPEAKER_CHANGE_DELAY)
      return () => clearTimeout(timeout)
    }
  }, [displayedParticipantId, mainParticipant])

  useEffect(() => {
    if (showParticipant1) {
      if (mainParticipant.id !== displayedParticipantId) {
        setParticipant2(mainParticipant)
      } else {
        setParticipant1(mainParticipant)
      }
    } else {
      if (mainParticipant.id !== displayedParticipantId) {
        setParticipant1(mainParticipant)
      } else {
        setParticipant2(mainParticipant)
      }
    }
  }, [displayedParticipantId, showParticipant1, mainParticipant])

  const ParticipantElement = participantElement

  return (
    <div className='main-speaker__container'>
      <div
        className={classNames('main-speaker__participant', {
          'main-speaker__participant--hidden': !showParticipant1,
        })}
        data-testid='participant1Element'
      >
        <ParticipantElement participant={participant1} />
      </div>
      <div
        className={classNames('main-speaker__participant', {
          'main-speaker__participant--hidden': showParticipant1,
        })}
        data-testid='participant2Element'
      >
        <ParticipantElement participant={participant2} />
      </div>
    </div>
  )
}

const PreviousButton: React.FC<{ onClick: () => void }> = ({ onClick }) => (
  <button
    className='participants-speaker-view__button participants-speaker-view__previous-button'
    onClick={onClick}
    aria-label='Previous'
  >
    <div className='participants-speaker-view__previous-button-icon' />
  </button>
)

const NextButton: React.FC<{ onClick: () => void }> = ({ onClick }) => (
  <button
    className='participants-speaker-view__button participants-speaker-view__next-button'
    onClick={onClick}
    aria-label='Next'
  >
    <div className='participants-speaker-view__next-button-icon' />
  </button>
)

==> client-sdk-react-1.13.0.tgz: package/src/components/Participants/ParticipantsSpeakerView/ParticipantsSpeakerView.tsx <==
import React, { useEffect, useState } from 'react'
import classNames from 'classnames'
import { Participant, ParticipantProps } from '../../Participant'
import { useZocksStore } from '../../../app'
import { ParticipantModel, selectLocalParticipant } from '../../../store'
import { usePagedParticipants, useSortRemoteParticipantsBySpeakers } from '../hooks'
import { MultipleParticipantViewProps } from '../model'
import './ParticipantsSpeakerView.scss'

export const ParticipantsSpeakerView: React.FC<MultipleParticipantViewProps> = ({
  pageSize = 4,
  participantElement,
}) => {
  const localParticipant = useZocksStore(selectLocalParticipant)

  const { remoteParticipantsSortedBySpeakers } = useSortRemoteParticipantsBySpeakers()
  const remoteParticipantsExist = !!remoteParticipantsSortedBySpeakers.length

  const mainParticipant = remoteParticipantsExist ? remoteParticipantsSortedBySpeakers[0] : localParticipant
  const allParticipants = [localParticipant, ...remoteParticipantsSortedBySpeakers]
  const { displayedParticipants, hasNextPage, hasPreviousPage, nextPage, previousPage } = usePagedParticipants(
    allParticipants,
    pageSize
  )

  const ParticipantElement = participantElement ?? Participant

  return (
    <div className='participants-speaker-view'>
      <div
        className={classNames('participants-speaker-view__active-speaker', {
          'participants-speaker-view__only-speaker': !remoteParticipantsExist,
        })}
      >
        {mainParticipant && (
          <ActiveSpeakerParticipant mainParticipant={mainParticipant} participantElement={ParticipantElement} />
        )}
      </div>
      {remoteParticipantsExist && (
        <>
          {hasPreviousPage && <PreviousButton onClick={previousPage} />}
          <div className='participants-speaker-view__others-container'>
            <div className='participants-speaker-view__others'>
              {displayedParticipants.map((participant) => (
                <ParticipantElement key={participant.id} participant={participant} />
              ))}
            </div>
          </div>
          {hasNextPage && <NextButton onClick={nextPage} />}
        </>
      )}
    </div>
  )
}

export const ActiveSpeakerParticipant: React.FC<{
  mainParticipant: ParticipantModel
  participantElement: React.FC<ParticipantProps>
}> = ({ mainParticipant, participantElement }) => {
  const SPEAKER_CHANGE_DELAY = 1000

  const [participant1, setParticipant1] = useState<ParticipantModel>(mainParticipant)
  const [participant2, setParticipant2] = useState<ParticipantModel>(mainParticipant)
  const [showParticipant1, setShowParticipant1] = useState<boolean>(true)

  const displayedParticipantId = showParticipant1 ? participant1.id : participant2.id

  useEffect(() => {
    if (mainParticipant.id !== displayedParticipantId) {
      const timeout = setTimeout(() => setShowParticipant1((showP1) => !showP1), SPEAKER_CHANGE_DELAY)
      return () => clearTimeout(timeout)
    }
  }, [displayedParticipantId, mainParticipant])

  useEffect(() => {
    if (showParticipant1) {
      if (mainParticipant.id !== displayedParticipantId) {
        setParticipant2(mainParticipant)
      } else {
        setParticipant1(mainParticipant)
      }
    } else {
      if (mainParticipant.id !== displayedParticipantId) {
        setParticipant1(mainParticipant)
      } else {
        setParticipant2(mainParticipant)
      }
    }
  }, [displayedParticipantId, showParticipant1, mainParticipant])

  const ParticipantElement = participantElement

  return (
    <div className='active-speaker__container'>
      <div
        className={classNames('active-speaker__participant', {
          'active-speaker__participant--hidden': !showParticipant1,
        })}
        data-testid='participant1Element'
      >
        <ParticipantElement participant={participant1} />
      </div>
      <div
        className={classNames('active-speaker__participant', {
          'active-speaker__participant--hidden': showParticipant1,
        })}
        data-testid='participant2Element'
      >
        <ParticipantElement participant={participant2} />
      </div>
    </div>
  )
}

const PreviousButton: React.FC<{ onClick: () => void }> = ({ onClick }) => (
  <button
    className='participants-speaker-view__button participants-speaker-view__previous-button'
    onClick={onClick}
    aria-label='Previous'
  >
    <div className='participants-speaker-view__previous-button-icon' />
  </button>
)

const NextButton: React.FC<{ onClick: () => void }> = ({ onClick }) => (
  <button
    className='participants-speaker-view__button participants-speaker-view__next-button'
    onClick={onClick}
    aria-label='Next'
  >
    <div className='participants-speaker-view__next-button-icon' />
  </button>
)
